#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
# License: GNU General Public License v2
#
# Author: thl-cmk[at]outlook[dot]com
# URL   : https://thl-cmk.hopto.org
# Date  : 2023-05-20

# based on https://github.com/allangood/check_mk/tree/master/plugins/squid
#
# rewritten for cmk 2.x
#
# 2023-05-20: moved to ~/local/lib/check_mk/gui/plugins/wato
#             renamed from check_squid.py to squid.py
#             changed client_reqps to client_requests
#             changed server_reqps to server_requests
#             changed cpu_time to cpu_usage
# 2023-12-02: add ip_address option for agent plugin
#             add available_number_of_file_descriptors for check section
# 2024-05-14: moved to check_parameters
#             separated WATO for bakery and check in two files
# 2025-03-08: added option to decide if the plugin should be installed

from cmk.gui.i18n import _
from cmk.gui.valuespec import (
    Dictionary,
    Integer,
    TextInput,
    DropdownChoice,
)
from cmk.gui.plugins.wato.utils import (
    HostRulespec,
    rulespec_registry,
)

try:
    from cmk.gui.cee.plugins.wato.agent_bakery.rulespecs.utils import (
        RulespecGroupMonitoringAgentsAgentPlugins,
    )
except ImportError:
    exit()


def _valuespec_agent_squid():
    return Dictionary(
        help=_('The plugin <tt>squid</tt> allows monitoring of Squid Web Proxies.'),
        title=_('Squid Web Proxy (Linux)'),
        elements=[
            ('install_plugin',
             DropdownChoice(
                 title=_('Install the plugin'),
                 choices=[
                     ('true', _('Install the plugin')),
                     ('false', _('Don\'t install the plugin'))
                 ],
                 default='true',
             )),
            ('ip_address',
             TextInput(
                 title=_('IP Address/Hostname'),
                 help=_('The IP-Address/Hostname squidclient connects to.'),
                 default_value='localhost',
             )),
            ('port',
             Integer(
                 title=_('Port number'),
                 help=_('TCP port number that squidclient connects to.'),
                 default_value=3128,
             )),
        ]
    )


rulespec_registry.register(
    HostRulespec(
        group=RulespecGroupMonitoringAgentsAgentPlugins,
        name='agent_config:squid',
        valuespec=_valuespec_agent_squid,
    )
)
